# 2023-03-20 - Composable Stable Pool V4

> ⚠️ **DEPRECATED: do not use** ⚠️
> This deployment has been deprecated in favor of a new version that is resilient to abrupt changes in the value reported by the tokens' rate providers: [`20230711-composable-stable-pool-v5`](../../20230711-composable-stable-pool-v5). This factory is unsafe to use with yield-bearing tokens in general and should not be used.

Deployment of `ComposableStablePoolFactory`, which allows creating Composable Stable Pools using `create2` instead of `create`.
Supersedes `20230206-composable-stable-pool-v3`.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet addresses](./output/arbitrum.json)
- [Optimism mainnet addresses](./output/optimism.json)
- [BSC mainnet addresses](./output/bsc.json)
- [Gnosis mainnet addresses](./output/gnosis.json)
- [Avalanche mainnet addresses](./output/avalanche.json)
- [Polygon zkeVM mainnet addresses](./output/zkevm.json)
- [Goerli testnet addresses](./output/goerli.json)
- [Sepolia testnet addresses](./output/sepolia.json)
- [`ComposableStablePoolFactory` artifact](./artifact/ComposableStablePoolFactory.json)
